@@ -61,7 +61,7 @@ class Status:
                     else:
                         self.father.framework.machine.task_state = False
 
-                    if not self.father.framework.package.handwheel.serial_status:
+                    if not self.father.framework.package.handwheel.status:
                         self.father.framework.package.handwheel.init_serial()
 
                     self.father.framework.utils.service.service_write({"command": "launch:machine:info", "message": "", "data": self.father.framework.machine.info})
